@@ -5,9 +5,9 @@ import glob, os, commands, sys
 
 setup(
     name = 'python-distutils-extra',
-    version = '0.90',
-    author = 'Sebastian Heinlein',
-    author_email = 'sebi@glatzor.de',
+    version = '2.10',
+    author = 'Sebastian Heinlein, Martin Pitt',
+    author_email = 'sebi@glatzor.de, martin.pitt@ubuntu.com',
     description = 'Add support for i18n, documentation and icons to distutils',
     packages = ['DistUtilsExtra', 'DistUtilsExtra.command'],
     license = 'GNU GPL',
@@ -18,6 +18,6 @@ setup(
            "build_icons = DistUtilsExtra.command.build_icons:build_icons",
            "build_help = DistUtilsExtra.command.build_help:build_help",
            "clean_i18n = DistUtilsExtra.command.clean_i18n:clean_i18n",
+           "check = DistUtilsExtra.command.check:check",
         ],},
-    test_suite = "nose.collector",
 )
